@@ -7,6 +7,8 @@ use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
 use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
 use charnames qw(:full :short);  # Unneeded in v5.16.
 
+use Capture::Tiny 'capture';
+
 use Data::Section::Simple 'get_data_section';
 
 use File::Which; # For which().
@@ -131,7 +133,7 @@ has valid_attributes =>
 	required => 0,
 );
 
-our $VERSION = '2.23';
+our $VERSION = '2.24';
 
 # -----------------------------------------------
 
@@ -529,6 +531,15 @@ sub load_valid_attributes
 		}
 	}
 
+	# Since V 2.24, output formats are no longer read from the __DATA__ section.
+	# Rather, they are extracted from the stderr output of 'dot -T?'.
+
+	my($stdout, $stderr)          = capture{system 'dot', '-T?'};
+	my(@field)                    = split(/one of:\s+/, $stderr);
+	$attribute{output_format}{$_} = 1 for split(/\s+/, $field[1]);
+
+	print "$_\n" for sort keys %{$attribute{output_format} };
+
 	$self -> valid_attributes(\%attribute);
 
 	return $self;
@@ -1649,12 +1660,31 @@ Here, [] indicates an optional parameter.
 
 =head2 Which version of Graphviz do you use?
 
-GraphViz2 targets V 2.30.1+ of L<Graphviz|http://www.graphviz.org/>.
+GraphViz2 targets V 2.34.0 of L<Graphviz|http://www.graphviz.org/>.
 
 This affects the list of available attributes per graph item (node, edge, cluster, etc) available.
 
 See the second column of the L<Graphviz attribute docs|http://www.graphviz.org/content/attrs> for details.
 
+See the next item for a discussion of the list of output formats.
+
+=head2 Where does the list of valid output formats come from?
+
+Up to V 2.23, it came from downloading and parsing http://www.graphviz.org/content/output-formats. This was done
+by scripts/extract.output.formats.pl.
+
+Starting with V 2.24 it comes from parsing the output of 'dot -T?'. The problems avoided, and advantages, of this are:
+
+=over 4
+
+=item o I might forget to run the script after Graphviz is updated
+
+=item o The on-line docs might be out-of-date
+
+=item o dot output includes the formats supported by locally-installed plugins
+
+=back
+
 =head2 Why do I get error messages like the following?
 
 	Error: <stdin>:1: syntax error near line 1
@@ -2628,43 +2658,3 @@ triangle
 tripleoctagon
 underline
 utr
-
-@@ output_format
-bmp
-canon
-cmap
-cmapx
-cmapx_np
-dot
-eps
-fig
-gd
-gd2
-gif
-gtk
-ico
-imap
-imap_np
-ismap
-jpe
-jpeg
-jpg
-pdf
-plain
-plain-ext
-png
-ps
-ps2
-svg
-svgz
-tif
-tiff
-vml
-vmlz
-vrml
-wbmp
-webp
-xdot
-xdot1.2
-xdot1.4
-xlib
